@@ -8,19 +8,13 @@ from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 from django.db.models import get_model
 from django.template.defaultfilters import slugify
-from django.utils.simplejson import dumps
+from json import dumps
 from treebeard.mp_tree import MP_Node
 import django.core.exceptions
 from treebeard.forms import MoveNodeForm
 
 settings = None
-try:
-    from django.conf import settings
-except ImportError:
-    # if we can't import settings, it just means
-    # they won't be able to get a list of available
-    # pageblock classes
-    pass
+from django.conf import settings
 
 
 class Hierarchy(models.Model):
@@ -243,6 +237,16 @@ class Section(MP_Node):
             return self.hierarchy.get_absolute_url()
         return self.get_parent().get_absolute_url() + self.slug + "/"
 
+    def get_edit_url(self):
+        if self.is_root():
+            return self.hierarchy.get_absolute_url() + "edit/"
+        return self.get_parent().get_edit_url() + self.slug + "/"
+
+    def get_instructor_url(self):
+        if self.is_root():
+            return self.hierarchy.get_absolute_url() + "instructor/"
+        return self.get_parent().get_instructor_url() + self.slug + "/"
+
     def get_path(self):
         """ same as get_absolute_url, without the leading /"""
         return self.get_absolute_url()[len(self.hierarchy.base_url):]
